/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "CRC16.hpp"
#include "Util/CRC.hpp"

#include <assert.h>

uint16_t
FLARM::CalculateCRC(const FrameHeader &header,
                    const void *data, size_t length)
{
  assert((data != nullptr && length > 0) ||
         (data == nullptr && length == 0));

  uint16_t crc = 0x00;

  crc = UpdateCRC16CCITT((const uint8_t *)&header, 6, crc);

  if (length == 0 || data == nullptr)
    return crc;

  crc = UpdateCRC16CCITT((const uint8_t *)data, length, crc);

  return crc;
}
